@@ -50,6 +50,8 @@ enum AttrTag : uint8_t {
     ATTR_IS_ASSIGNED, // to suppress usage warnings
     ATTR_IS_USED,     // to suppress usage warnings
     ATTR_ORDERED,     // used to store tables in ordered mode
+    ATTR_NO_ZAM_OPT,  // avoid ZAM optimization
+    ATTR_NO_CPP_OPT,  // avoid -O gen-C++ optimization
     NUM_ATTRS         // this item should always be last
 };
 
@@ -65,8 +67,6 @@ public:
     Attr(AttrTag t, ExprPtr e);
     explicit Attr(AttrTag t);
 
-    ~Attr() override = default;
-
     AttrTag Tag() const { return tag; }
 
     const ExprPtr& GetExpr() const { return expr; }
@@ -108,10 +108,14 @@ protected:
 // Manages a collection of attributes.
 class Attributes final : public Obj {
 public:
-    Attributes(std::vector<AttrPtr> a, TypePtr t, bool in_record, bool is_global);
-    Attributes(TypePtr t, bool in_record, bool is_global);
+    Attributes(std::vector<AttrPtr> a, TypePtr t, bool in_record, bool is_global, bool is_param);
+
+    Attributes(TypePtr t, bool in_record, bool is_global)
+        : Attributes(std::vector<AttrPtr>{}, std::move(t), in_record, is_global, false) {}
+
+    Attributes(std::vector<AttrPtr> a, TypePtr t, bool in_record, bool is_global)
+        : Attributes(std::move(a), std::move(t), in_record, is_global, false) {}
 
-    ~Attributes() override = default;
 
     void AddAttr(AttrPtr a, bool is_redef = false);
 
@@ -132,7 +136,7 @@ public:
 
 protected:
     // Returns true if the attribute is okay, false if not.
-    bool CheckAttr(Attr* attr);
+    bool CheckAttr(Attr* attr, const TypePtr& attrs_t);
 
     // Reports an attribute error and returns false (handy for CheckAttr()).
     bool AttrError(const char* msg);
@@ -142,6 +146,7 @@ protected:
 
     bool in_record;
     bool global_var;
+    bool is_param;
 };
 
 // Checks whether default attribute "a" is compatible with the given type.
