@@ -281,7 +281,7 @@ public:
 
     // True if (a) the expression has at least one operand, and (b) all
     // of its operands are constant.
-    bool HasConstantOps() const {
+    virtual bool HasConstantOps() const {
         return GetOp1() && GetOp1()->IsConst() &&
                (! GetOp2() || (GetOp2()->IsConst() && (! GetOp3() || GetOp3()->IsConst())));
     }
@@ -1342,7 +1342,6 @@ extern RecordValPtr coerce_to_record(RecordTypePtr rt, Val* v, const std::vector
 class TableCoerceExpr final : public UnaryExpr {
 public:
     TableCoerceExpr(ExprPtr op, TableTypePtr r, bool type_check = true);
-    ~TableCoerceExpr() override = default;
 
     // Optimization-related:
     ExprPtr Duplicate() override;
@@ -1354,7 +1353,6 @@ protected:
 class VectorCoerceExpr final : public UnaryExpr {
 public:
     VectorCoerceExpr(ExprPtr op, VectorTypePtr v);
-    ~VectorCoerceExpr() override = default;
 
     // Optimization-related:
     ExprPtr Duplicate() override;
@@ -1370,7 +1368,6 @@ protected:
 class ScheduleTimer final : public Timer {
 public:
     ScheduleTimer(const EventHandlerPtr& event, zeek::Args args, double t);
-    ~ScheduleTimer() override = default;
 
     void Dispatch(double t, bool is_expire) override;
 
@@ -1554,7 +1551,7 @@ public:
     bool IsPure() const override;
 
     // True if the entire list represents constant values.
-    bool HasConstantOps() const;
+    bool HasConstantOps() const override;
 
     ValPtr Eval(Frame* f) const override;
 
@@ -1681,7 +1678,7 @@ extern const char* assign_to_index(ValPtr v1, ValPtr v2, ValPtr v3, bool& iterat
 inline Val* Expr::ExprVal() const {
     if ( ! IsConst() )
         BadTag("ExprVal::Val", expr_name(tag), expr_name(EXPR_CONST));
-    return ((ConstExpr*)this)->Value();
+    return (static_cast<const ConstExpr*>(this))->Value();
 }
 
 // Decides whether to return an AssignExpr or a RecordAssignExpr.
@@ -1715,6 +1712,11 @@ extern bool check_and_promote_exprs_to_type(ListExpr* elements, TypePtr type);
 // if they couldn't all be reduced.
 extern std::optional<std::vector<ValPtr>> eval_list(Frame* f, const ListExpr* l);
 
+// Evaluates an expression in isolation (without a frame context).
+// Used for compile-time constant evaluation and attribute processing.
+extern ValPtr eval_in_isolation(const Expr* e);
+inline ValPtr eval_in_isolation(const ExprPtr& e) { return eval_in_isolation(e.get()); }
+
 // Returns true if e1 is "greater" than e2 - here "greater" is just
 // a heuristic, used with commutative operators to put them into
 // a canonical form.
