@@ -96,7 +96,7 @@ using DataBlockMap = std::map<uint64_t, DataBlock>;
  */
 class DataBlockList {
 public:
-    DataBlockList() {}
+    DataBlockList() = default;
 
     DataBlockList(Reassembler* r) : reassembler(r) {}
 
@@ -117,7 +117,7 @@ public:
      * Must not be called when the list is empty.
      */
     const DataBlock& FirstBlock() const {
-        assert(block_map.size());
+        assert(! block_map.empty());
         return block_map.begin()->second;
     }
 
@@ -126,7 +126,7 @@ public:
      * Must not be called when the list is empty.
      */
     const DataBlock& LastBlock() const {
-        assert(block_map.size());
+        assert(! block_map.empty());
         return block_map.rbegin()->second;
     }
 
@@ -237,7 +237,6 @@ private:
 class Reassembler : public Obj {
 public:
     Reassembler(uint64_t init_seq, ReassemblerType reassem_type = REASSEM_UNKNOWN);
-    ~Reassembler() override {}
 
     void NewBlock(double t, uint64_t seq, uint64_t len, const u_char* data);
 
