@@ -102,7 +102,7 @@ protected:
     ExprPtr e;
 };
 
-class IfStmt final : public ExprStmt {
+class IfStmt : public ExprStmt {
 public:
     IfStmt(ExprPtr test, StmtPtr s1, StmtPtr s2);
     ~IfStmt() override;
@@ -135,6 +135,14 @@ protected:
     StmtPtr s2;
 };
 
+class DebugIfStmt final : public IfStmt {
+public:
+    DebugIfStmt(ExprPtr test, StmtPtr s1, StmtPtr s2) : IfStmt(test, s1, s2) {}
+
+protected:
+    ValPtr DoExec(Frame* f, Val* v, StmtFlowType& flow) override;
+};
+
 class Case final : public Obj {
 public:
     Case(ListExprPtr c, IDPList* types, StmtPtr arg_s);
@@ -194,7 +202,7 @@ protected:
 
     int DefaultCaseIndex() const { return default_case_idx; }
     const auto& ValueMap() const { return case_label_value_map; }
-    const std::vector<std::pair<ID*, int>>* TypeMap() const { return &case_label_type_list; }
+    const std::vector<std::pair<IDPtr, int>>* TypeMap() const { return &case_label_type_list; }
     const CompositeHash* CompHash() const { return comp_hash; }
 
     ValPtr DoExec(Frame* f, Val* v, StmtFlowType& flow) override;
@@ -212,20 +220,20 @@ protected:
     // Adds an entry in case_label_type_map for the given type (w/ ID) to
     // associate it with the given index in the cases list.  If an entry
     // for the type already exists, returns false; else returns true.
-    bool AddCaseLabelTypeMapping(ID* t, int idx);
+    bool AddCaseLabelTypeMapping(IDPtr t, int idx);
 
     // Returns index of a case label that matches the value, or
     // default_case_idx if no case label matches (which may be -1 if
     // there's no default label). The second tuple element is the ID of
     // the matching type-based case if it defines one.
-    std::pair<int, ID*> FindCaseLabelMatch(const Val* v) const;
+    std::pair<int, IDPtr> FindCaseLabelMatch(const Val* v) const;
 
     case_list* cases = nullptr;
     int default_case_idx = -1;
     CompositeHash* comp_hash = nullptr;
     std::unordered_map<const Val*, int> case_label_value_map;
     PDict<int> case_label_hash_map;
-    std::vector<std::pair<ID*, int>> case_label_type_list;
+    std::vector<std::pair<IDPtr, int>> case_label_type_list;
 };
 
 class EventStmt final : public ExprStmt {
@@ -416,7 +424,6 @@ public:
 class StmtList : public Stmt {
 public:
     StmtList();
-    ~StmtList() override = default;
 
     ValPtr Exec(Frame* f, StmtFlowType& flow) override;
 
@@ -452,6 +459,13 @@ protected:
     void ResetStmts(std::vector<StmtPtr> new_stmts) { stmts = std::move(new_stmts); }
 };
 
+class DebugStmtList : public StmtList {
+public:
+    DebugStmtList() = default;
+
+    ValPtr Exec(Frame* f, StmtFlowType& flow) override;
+};
+
 class InitStmt final : public Stmt {
 public:
     explicit InitStmt(std::vector<IDPtr> arg_inits);
@@ -584,6 +598,7 @@ public:
     double TimeoutVal(Frame* f);
 
     FuncType::CaptureList* Captures() { return cl; }
+    const FuncType::CaptureList* Captures() const { return cl; }
 
     bool IsReturn() const { return is_return; }
 
@@ -661,6 +676,8 @@ public:
     StmtPtr TimeoutBody() const { return wi->TimeoutStmt(); }
     bool IsReturn() const { return wi->IsReturn(); }
 
+    const FuncType::CaptureList* Captures() const { return wi->Captures(); }
+
     auto Info() const { return wi; }
 
     void StmtDescribe(ODesc* d) const override;
