@@ -43,7 +43,7 @@ using ListExprPtr = IntrusivePtr<ListExpr>;
 // The following tracks how to initialize a given record field.
 class FieldInit {
 public:
-    virtual ~FieldInit() {}
+    virtual ~FieldInit() = default;
 
     // Return the initialization value of the field.
     virtual ZVal Generate() const = 0;
@@ -214,7 +214,10 @@ public:
     const TableType* AsTableType() const;
     TableType* AsTableType();
 
+    [[deprecated("Remove in v9.1. Use AsTableType() instead.")]]
     const SetType* AsSetType() const;
+
+    [[deprecated("Remove in v9.1. Use AsTableType() instead.")]]
     SetType* AsSetType();
 
     const RecordType* AsRecordType() const;
@@ -270,9 +273,7 @@ public:
     /**
      * Returns true if the given type name has any declared aliases
      */
-    static bool HasAliases(std::string_view type_name) {
-        return Type::type_aliases.find(type_name) != Type::type_aliases.end();
-    }
+    static bool HasAliases(std::string_view type_name) { return Type::type_aliases.contains(type_name); }
 
     /**
      * Returns the set of all type names declared as an aliases to the given
@@ -319,8 +320,6 @@ class TypeList final : public Type {
 public:
     explicit TypeList(TypePtr arg_pure_type = nullptr) : Type(TYPE_LIST), pure_type(std::move(arg_pure_type)) {}
 
-    ~TypeList() override = default;
-
     const std::vector<TypePtr>& GetTypes() const { return types; }
 
     bool IsPure() const { return pure_type != nullptr; }
@@ -356,8 +355,6 @@ protected:
 
 class IndexType : public Type {
 public:
-    ~IndexType() override = default;
-
     int MatchesIndex(detail::ListExpr* index) const override;
 
     const TypeListPtr& GetIndices() const { return indices; }
@@ -438,7 +435,7 @@ private:
     bool reported_error = false;
 };
 
-class SetType final : public TableType {
+class [[deprecated("Remove in v9.1. Use TableType instead.")]] SetType final : public TableType {
 public:
     SetType(TypeListPtr ind, detail::ListExprPtr arg_elements);
     ~SetType() override;
@@ -625,6 +622,8 @@ public:
     TypePtr type;
     detail::AttributesPtr attrs;
     const char* id = nullptr;
+    bool is_managed = false;
+    TypeTag tag = TYPE_ERROR;
 
 private:
     detail::Location loc = detail::GetCurrentLocation();
@@ -684,12 +683,16 @@ public:
     type_decl_list* Types() { return types; }
 
     // Given an offset, returns the field's TypeDecl.
-    const TypeDecl* FieldDecl(int field) const;
-    TypeDecl* FieldDecl(int field);
+    const TypeDecl* FieldDecl(int field) const { return (*types)[field]; }
+    TypeDecl* FieldDecl(int field) { return (*types)[field]; }
 
     // Returns flags corresponding to which fields in the record
     // have types requiring memory management (reference counting).
-    const std::vector<bool>& ManagedFields() const { return managed_fields; }
+    [[deprecated(
+        "Remove in v9.1: Unused and optimization related internal. Use TypeDecl's is_managed member instead.")]]
+    const std::vector<bool>& ManagedFields() const {
+        return managed_fields;
+    }
 
     int NumFields() const { return num_fields; }
     int NumOrigFields() const { return num_orig_fields; }
@@ -770,6 +773,7 @@ private:
 
     // If we were willing to bound the size of records, then we could
     // use std::bitset here instead.
+    // Remove in v9.1: Accessor is removed so this should be unused.
     std::vector<bool> managed_fields;
 
     // Number of fields in the type.
@@ -802,14 +806,13 @@ class OpaqueType final : public Type {
 public:
     explicit OpaqueType(const std::string& name);
     TypePtr ShallowClone() override { return make_intrusive<OpaqueType>(name); }
-    ~OpaqueType() override {};
 
     const std::string& Name() const { return name; }
 
     void DescribeReST(ODesc* d, bool roles_only = false) const override;
 
 protected:
-    OpaqueType() {}
+    OpaqueType() = default;
 
     void DoDescribe(ODesc* d) const override;
 
@@ -1044,7 +1047,10 @@ inline const TypePtr& error_type() { return base_type(TYPE_ERROR); }
 
 extern zeek::OpaqueTypePtr md5_type;
 extern zeek::OpaqueTypePtr sha1_type;
+extern zeek::OpaqueTypePtr sha224_type;
 extern zeek::OpaqueTypePtr sha256_type;
+extern zeek::OpaqueTypePtr sha384_type;
+extern zeek::OpaqueTypePtr sha512_type;
 extern zeek::OpaqueTypePtr entropy_type;
 extern zeek::OpaqueTypePtr cardinality_type;
 extern zeek::OpaqueTypePtr topk_type;
