@@ -48,12 +48,12 @@ struct WriteContext {
     WriteIdx idx = 0; // Ever increasing counter.
 
     bool operator<(const WriteContext& o) const {
-        assert(id == o.id);
+        assert(id->Get() == o.id->Get());
         return idx < o.idx;
     }
 
     bool operator==(const WriteContext& o) const {
-        assert(id == o.id);
+        assert(id->Get() == o.id->Get());
         return idx == o.idx;
     }
 };
@@ -339,6 +339,11 @@ public:
      */
     bool Flush(EnumVal* id);
 
+    /**
+     * Flushes all log streams including all associated writers.
+     */
+    void FlushAll();
+
     /**
      * Signals the manager to shutdown at Zeek's termination.
      */
@@ -391,9 +396,6 @@ protected:
     bool FinishedRotation(WriterFrontend* writer, const char* new_name, const char* old_name, double open, double close,
                           bool success, bool terminating);
 
-    // Flush write buffers of all writers.
-    void FlushAllWriteBuffers();
-
     // Start the regular log flushing timer.
     void StartLogFlushTimer();
 
@@ -422,8 +424,8 @@ private:
     bool TraverseRecord(Stream* stream, Filter* filter, RecordType* rt, TableVal* include, TableVal* exclude,
                         const std::string& path, const std::list<int>& indices);
 
-    detail::LogRecord RecordToLogRecord(const Stream* stream, Filter* filter, RecordVal* columns, size_t& total_size);
-    threading::Value ValToLogVal(std::optional<ZVal>& val, Type* ty, size_t& total_size);
+    detail::LogRecord RecordToLogRecord(WriterInfo* info, Filter* filter, const Stream* stream, RecordVal* columns);
+    threading::Value ValToLogVal(WriterInfo* info, const Stream* stream, std::optional<ZVal>& val, Type* ty);
 
     Stream* FindStream(EnumVal* id);
     void RemoveDisabledWriters(Stream* stream);
@@ -448,11 +450,17 @@ private:
     int rotations_pending = 0;    // Number of rotations not yet finished.
     FuncPtr rotation_format_func;
     FuncPtr log_stream_policy_hook;
+
     size_t max_log_record_size = 0;
+    size_t total_record_size = 0;
+    size_t total_string_bytes = 0;
+    size_t total_container_elements = 0;
 
     std::shared_ptr<telemetry::CounterFamily> total_log_stream_writes_family;
     std::shared_ptr<telemetry::CounterFamily> total_log_writer_writes_family;
     std::shared_ptr<telemetry::CounterFamily> total_log_writer_discarded_writes_family;
+    std::shared_ptr<telemetry::CounterFamily> total_log_writer_truncated_string_fields_family;
+    std::shared_ptr<telemetry::CounterFamily> total_log_writer_truncated_container_fields_family;
 
     zeek_uint_t last_delay_token = 0;
     std::vector<detail::WriteContext> active_writes;
