@@ -101,13 +101,13 @@
 #define SIN_LEN
 
 /* The size of `long int', as computed by sizeof. */
-#define SIZEOF_LONG_INT 8
+#define SIZEOF_LONG_INT 4
 
 /* The size of `long long', as computed by sizeof. */
 #define SIZEOF_LONG_LONG 8
 
 /* The size of `void *', as computed by sizeof. */
-#define SIZEOF_VOID_P 8
+#define SIZEOF_VOID_P 4
 
 /* should we declare syslog() and openlog() */
 /* #undef SYSLOG_INT */
@@ -143,7 +143,7 @@
 #define USE_SQLITE
 
 /* whether words are stored with the most significant byte first */
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN
 
 /* whether htonll/ntohll is defined in <arpa/inet.h> */
 /* #undef HAVE_BYTEORDER_64 */
@@ -250,7 +250,7 @@
 /* #undef ENABLE_SPICY_SSL */
 
 /* String with host architecture (e.g., "linux-x86_64") */
-#define HOST_ARCHITECTURE "openbsd-arm64"
+#define HOST_ARCHITECTURE "openbsd-macppc"
 
 /* String with extension of dynamic libraries (e.g., ".so") */
 #define DYNAMIC_PLUGIN_SUFFIX ".so"
